==> portal-contribuinte-3.081.1.zip: BOOT-INF/classes/sql/simam/conferencia/LancamentoCredito.sql <==
select 01                                 as codigoArquivo,
       'Lançamento de Créditos'           as arquivo,
       'CREDITO'                          as tipoArquivo,
       sum(coalesce(arquivo.valor, 0))    as valorArquivo,
       sum(coalesce(integracao.valor, 0)) as valorIntegrado
from (select 'Integração',
             ip.datamovimento            as data,
             sum(coalesce(iip.valor, 0)) as valor
      from integracaopatrimonial ip
               left join itemintegracaopatrimonial iip on ip.id = iip.idintegracaopatrimonial
               left join tribreceita r
                         on r.receita = iip.tributo and r.exercicio = ip.exercicio and r.entidade = ip.entidade
               JOIN tribreceitatipo trt
                    ON trt.tiporeceita = r.tiporeceita
      where ip.entidade = :entidade
        and ip.datamovimento between :dataInicial and :dataFinal
        and iip.tipomovimento = 'INSCRICAO'
        and trt.classificacaoreceitatipo IN (1, 2, 3, 4, 5, 7)
        and iip.situacaolegal = 0
        and ip.situacaointegracaopatrimonial != 'ESTORNADO_CONTABILIDADE'
      group by ip.datamovimento) as integracao
         full outer join (
    select 'Arquivo', tlc.dtlancamento, sum(coalesce(tdlc.valor, 0)) as valor
    from tceLancCredito tlc
             join tcedebitolanccredito tdlc on tdlc.idtcelanccredito = tlc.idtcelanccredito

    where tlc.dtlancamento between :dataInicial and :dataFinal
    group by tlc.dtlancamento) as arquivo
         on arquivo.dtlancamento = integracao.data

==> portal-contribuinte-3.096.0.zip: BOOT-INF/classes/sql/simam/conferencia/LancamentoCredito.sql <==
select 01                                 as codigoArquivo,
       'Lançamento de Créditos'           as arquivo,
       'CREDITO'                          as tipoArquivo,
       sum(coalesce(arquivo.valor, 0))    as valorArquivo,
       sum(coalesce(integracao.valor, 0)) as valorIntegrado,
       sum(coalesce(retencao.valor, 0))   as valorRetencao
from (select 'Integração',
             ip.datamovimento            as data,
             sum(coalesce(iip.valor, 0)) as valor
      from integracaopatrimonial ip
               left join itemintegracaopatrimonial iip on ip.id = iip.idintegracaopatrimonial
               left join tribreceita r
                         on r.receita = iip.tributo and r.exercicio = ip.exercicio and r.entidade = ip.entidade
               JOIN tribreceitatipo trt
                    ON trt.tiporeceita = r.tiporeceita
      where ip.entidade = :entidade
        and ip.datamovimento between :dataInicial and :dataFinal
        and iip.tipomovimento = 'INSCRICAO'
        and trt.classificacaoreceitatipo IN (1, 2, 3, 4, 5, 7)
        and iip.situacaolegal = 0
        and ip.situacaointegracaopatrimonial != 'ESTORNADO_CONTABILIDADE'
      group by ip.datamovimento) as integracao
         full outer join (
    select 'Arquivo', tlc.dtlancamento, sum(coalesce(tlc.vlLancamento, 0)) as valor
    from tceLancCredito tlc
    where tlc.dtlancamento between :dataInicial and :dataFinal
      and tlc.idtipooperacaocredito <> 2
    group by tlc.dtlancamento) as arquivo
                         on arquivo.dtlancamento = integracao.data
         full outer join (
    select 'Retenção', rc.dtlancamento ,coalesce(sum(rc.valor), 0) as valor from tceretencaocontabil rc
    where dtlancamento between :dataInicial and :dataFinal
    group by dtlancamento
) as retencao
    on retencao.dtlancamento = integracao.data
